jQuery UI shake-effect documentation

## Shake Effect

Description: Shakes the element multiple times, vertically or horizontally.

- #### shake

  - direction (default: `"both"`)
    Type: String
    The direction of the effect. Possible values: `"left"`, `"right"`, `"up"`, `"down"`.
  - distance (default: `20`)
    Type: Number
    Distance to shake.
  - times (default: `3`)
    Type: Integer
    Times to shake.

## Example:

#### Shake a div.

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | `<!doctype html>` `<``html` `lang``=``"en"``>` `<``head``>` `` `<``meta` `charset``=``"utf-8"``>` `` `<``title``>shake demo</``title``>` `` `<``link` `rel``=``"stylesheet"` `href``=``"http://code.jquery.com/ui/1.9.2/themes/base/jquery-ui.css"``>` `` `<``style``>` `` `#toggle {` `` `width: 100px;` `` `height: 100px;` `` `background: #ccc;` `` `}` `` `</``style``>` `` `<``script` `src``=``"http://code.jquery.com/jquery-1.8.3.js"``></``script``>` `` `<``script` `src``=``"http://code.jquery.com/ui/1.9.2/jquery-ui.js"``></``script``>` `</``head``>` `<``body``>` `<``p``>Click anywhere to shake the box.</``p``>` `<``div` `id``=``"toggle"``></``div``>` `<``script``>` `$( document ).click(function() {` `` `$( "#toggle" ).effect( "shake" );` `});` `</``script``>` `</``body``>` `</``html``>`

#### Demo: